==> nextcloud-25.0.12p1.tgz: nextcloud/apps/comments/l10n/zh_TW.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "留言",
    "You commented" : "您已留言",
    "{author} commented" : "{author} 已留言",
    "You commented on %1$s" : "您已對 %1$s 留言",
    "You commented on {file}" : "您已對 {file} 留言",
    "%1$s commented on %2$s" : "%1$s 已對 %2$s 留言",
    "{author} commented on {file}" : "{author} 已對 {file} 留言",
    "<strong>Comments</strong> for files" : "檔案的<strong>留言</strong>",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "一個已被刪除的使用者在「{file}」的留言中提到您",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} 在「{file}」的留言中提到您",
    "Files app plugin to add comments to files" : "用於對檔案加入留言的檔案應用程式擴充元件",
    "Edit comment" : "編輯留言",
    "Delete comment" : "刪除留言",
    "Cancel edit" : "取消編輯",
    "Post comment" : "張貼留言",
    "No comments yet, start the conversation!" : "尚無留言，開始討論！",
    "No more messages" : "沒有更多訊息",
    "Retry" : "重試",
    "Failed to mark comments as read" : "無法將留言標記為已讀",
    "Unable to load the comments list" : "無法載入留言列表",
    "_1 new comment_::_{unread} new comments_" : ["{unread} 則新留言"],
    "Comment" : "留言",
    "An error occurred while trying to edit the comment" : "嘗試編輯此留言時錯誤",
    "Comment deleted" : "留言已刪除",
    "An error occurred while trying to delete the comment" : "嘗試刪除留言時發生錯誤",
    "An error occurred while trying to create the comment" : "嘗試建立留言時發生錯誤",
    "%1$s commented" : "%1$s 已留言",
    "_%n unread comment_::_%n unread comments_" : ["%n 則未讀留言"]
},
"nplurals=1; plural=0;");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/comments/l10n/zh_TW.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "留言",
    "You commented" : "您已留言",
    "{author} commented" : "{author} 已留言",
    "You commented on %1$s" : "您已對 %1$s 留言",
    "You commented on {file}" : "您已對 {file} 留言",
    "%1$s commented on %2$s" : "%1$s 已對 %2$s 留言",
    "{author} commented on {file}" : "{author} 已對 {file} 留言",
    "<strong>Comments</strong> for files" : "檔案的<strong>留言</strong>",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "一個已被刪除的使用者在「{file}」的留言中提到您",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} 在「{file}」的留言中提到您",
    "Files app plugin to add comments to files" : "用於對檔案加入留言的檔案應用程式擴充元件",
    "Edit comment" : "編輯留言",
    "Delete comment" : "刪除留言",
    "Cancel edit" : "取消編輯",
    "New comment" : "新留言",
    "Write a comment …" : "編寫留言……",
    "Post comment" : "張貼留言",
    "@ for mentions, : for emoji, / for smart picker" : "@ 表示提及、: 表示表情符號、/ 表示智慧型選取程式",
    "Could not reload comments" : "無法重新載入留言",
    "No comments yet, start the conversation!" : "尚無留言，開始討論！",
    "No more messages" : "沒有更多訊息",
    "Retry" : "重試",
    "Failed to mark comments as read" : "無法將留言標記為已讀",
    "Unable to load the comments list" : "無法載入留言列表",
    "_1 new comment_::_{unread} new comments_" : ["{unread} 則新留言"],
    "Comment" : "留言",
    "An error occurred while trying to edit the comment" : "嘗試編輯此留言時錯誤",
    "Comment deleted" : "留言已刪除",
    "An error occurred while trying to delete the comment" : "嘗試刪除留言時發生錯誤",
    "An error occurred while trying to create the comment" : "嘗試建立留言時發生錯誤",
    "_%n unread comment_::_%n unread comments_" : ["%n 則未讀留言"]
},
"nplurals=1; plural=0;");
